# django-app-creator

`django-app-creator` est un outil en ligne de commande qui permet de générer rapidement la structure d'une application Django avec une organisation personnalisée.

## Fonctionnalités

- Crée automatiquement une application Django avec :
  - Un dossier `models/` contenant un fichier `__init__.py`
  - Un dossier `views/` contenant un fichier `__init__.py`
  - Un fichier `urls.py` prêt à l’emploi
- Permet de standardiser et accélérer la création d'apps dans un projet Django

## Installation

1. Placez-vous dans le dossier du projet contenant `setup.py` :

```bash
cd django-app-creator
